#
# spec file for package exaile
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __requires_exclude typelib\\((GtkosxApplication)\\)
%define _name   Exaile
Name:           exaile
Version:        4.1.3
Release:        1.2
Summary:        GTK Amarok-like music player
License:        GPL-3.0-or-later
URL:            https://www.exaile.org/
Source:         https://github.com/exaile/exaile/releases/download/%{version}/%{name}-%{version}.tar.gz
# PATCH-FEATURE-OPENSUSE exaile-no-splash-default.patch sor.alexei@meowr.ru -- Do not show splash screen on startup by default.
Patch0:         %{name}-no-splash-default.patch
# PATCH-FEATURE-OPENSUSE exaile-mate-screensaver.patch sor.alexei@meowr.ru -- Make the screensaverpause plugin work with MATE Screensaver.
Patch1:         %{name}-mate-screensaver.patch
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  gobject-introspection-devel
BuildRequires:  help2man
BuildRequires:  python3
BuildRequires:  python3-gobject
BuildRequires:  update-desktop-files
Requires:       gdk-pixbuf-loader-rsvg
Requires:       gstreamer
Requires:       gstreamer-plugins-good
Requires:       python3-berkeleydb
Requires:       python3-cairo
Requires:       python3-dbus-python
Requires:       python3-feedparser
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
Requires:       python3-gobject-cairo
Requires:       python3-mutagen >= 1.10
Recommends:     %{name}-lang
Recommends:     gstreamer-plugins-bad
Recommends:     gstreamer-plugins-ugly
# Will be python3-discid in Exaile 4.1.3
Recommends:     python3-CDDB
Recommends:     python3-Pillow
Recommends:     python3-gpod
Recommends:     python3-zeroconf
Recommends:     udisks2
BuildArch:      noarch

%description
Exaile is a media player aiming to be similar to Clementine, but
written in GTK+.

It incorporates many of the cool things from Amarok (and other
media players) like automatic fetching of album art, handling of
large libraries, lyrics fetching, artist/album information via the
wikipedia, last.fm support, optional iPod support (assuming you
have python-gpod installed).

In addition, Exaile also includes a built in shoutcast directory
browser, tabbed playlists (so you can have more than one playlist
open at a time), blacklisting of tracks (so they don't get scanned
into your library), downloading of guitar tablature from
fretplay.com, and submitting played tracks on your iPod to last.fm.

%lang_package

%prep
%autosetup -p1

%build
%make_build

%install
%make_install \
  LIBINSTALLDIR=%{_datadir} \
  PREFIX=%{_prefix}

dirname $(find %{buildroot}%{_datadir} -type f -name '*.py') | sort -u | while read dir; do
    pushd "$dir"
    # Fix wrong-script-end-of-line-encoding.
    dos2unix *.py
    # Fix python-bytecode-inconsistent-mtime (hacky).
    rm -f *.pyc *.pyo
    touch -c *.py
    %py3_compile .
    popd
done

%fdupes %{buildroot}%{_prefix}/
%find_lang %{name}

%files
%license COPYING
%doc README.md
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/*
%dir %{_datadir}/icons/hicolor/*/apps/
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/metainfo/*%{name}.appdata.xml
%{_mandir}/man?/%{name}.?%{?ext_man}
%dir %{_datadir}/dbus-1/
%dir %{_datadir}/dbus-1/services/
%{_datadir}/dbus-1/services/org.%{name}.%{_name}.service
%dir %{_sysconfdir}/xdg/%{name}/
%config %{_sysconfdir}/xdg/%{name}/settings.ini
%dir %{_datadir}/bash-completion/
%dir %{_datadir}/bash-completion/completions/
%{_datadir}/bash-completion/completions/%{name}
%dir %{_datadir}/fish/
%dir %{_datadir}/fish/vendor_completions.d/
%{_datadir}/fish/vendor_completions.d/%{name}.fish

%files lang -f %{name}.lang

%changelog
* Fri Jan 17 2025 Markéta Machová <mmachova@suse.com>
- Update to version 4.1.3
  * Adding support for tagging aac files with id3 tags
  * Change flac/ogg metadata handling for bpm and comment
  * Experimental: Save star ratings to media files
  * Track start and end is now triggered also for streams
  * AppData files now uses more translations
  * Added preference to remove a track from queue after playing
  * Users can override built-in plugins with newer versions and
    remove the overrides as well
  * Users can remove custom installed plugins via plugin manager
  * BerkeleyDB is used instead of bsddb, if available
* Sat May  6 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 4.1.2:
  * Fix sorting on Rating column when there are unrated tracks.
  * Fix a bug causing the tracklist to scroll to the top when
    adding or reordering tracks.
  * Fix a bug causing the window title to not update on track
    change if the current track has been paused.
  * The status bar can now be hidden.
  * The stop button does not move around anymore when hovered for
    the first time.
  * Fix error if files are removed during scan.
  * Playlist columns are added next to the currently selected
    column.
  * The status bar now does not ignore zero track counts; they are
    displayed as normal.
  * Log files now created only when/if we write something to it.
  * New callback while installing plugins.
  * Fix test warnings.
  * Work around potential hang when running tests.
  * Tests do not depend on mox3 anymore.
  * When running tests with make test, PYTHONPATH is now only
    prepended to, instead of being replaced.
  * Update translations.
  * Plugins:
    + inhibitsuspend: Add support for Sway.
    + notify: Fix wrong text: "by {album}" should be
    "from {album}".
    + previewdevice: Will be shown after disabling and enabling
    again.
    + quickbuttons: This is a new plugin providing quick shortcuts
    to some settings.
* Fri May  6 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 4.1.1
  * Restored Python 3.6 compatibility, broken since 4.1.0-beta1
  * The last playlist export directory is now saved between calls
    and between sessions
  * Added tooltip text to the Clear buttons in the Properties dialog
  * Plugins:
  * console: When encountering a very long "word", the console will
    now wrap between characters instead of widening the window to
    fit the word.
  * grouptagger: Fixed i18n issues in some strings. Translations
    for these strings may be broken until they are updated.
  * Translation updates: Catalan, Croatian, Greek, Sinhala, Spanish.
* Sun Feb 21 2021 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 4.1.0 (changes since 4.1.0~alpha1):
  * Fix an issue causing the Track Properties dialogue to
    (very rarely) fail to open.
  * The seek time display now ignores GtkProgressBar's text
    formatting. On Adwaita, this makes the text easier to read
    (higher contrast, bigger).
  * The Track Properties dialogue now correctly sets the parent
    window when opened from a panel.
  * Collection Manager now displays local paths when possible
    instead of always URIs.
  * Collection Manager now prevents adding the same library
    location twice.
  * The Track Properties dialogue no longer changes the
    capitalisation of known tag names (for example, ISRC used to be
    displayed as Isrc).
  * Fix an issue causing errors when running Exaile on Python 3.9.
  * Fix a bug preventing the Device Manager window from opening.
  * Fix running the test suite on non-English locales.
  * Plugins:
    + daapclient: Now uses python-zeroconf instead of Avahi for
    share auto-discovery.
    + ipconsole: Compatibility fixes for recent IPython versions.
    + screensaverpause: Xfce Screensaver is now supported.
    + moodbar: Restore compatibility with the previewdevice plugin.
    + moodbar: Make this work again.
    + notify: Fix incompatibility with Python >= 3.8.
    + console plugin: Fix a bug causing the expression printing to
    only work once.
  * Update translations.
* Thu Jun  4 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 4.1.0~alpha1 (changes since 4.0.2):
  * Port to Python 3.
  * The Files panel dropdown list now also lists filesystem mounts.
  * Fix a crash when fetching covers with the Cover Manager.
  * Some dialogues that were previously orphaned now have parents.
  * Allow -symbolic fallback and SVG on some icons.
  * Update the .mod file support to work with latest libmodplug.
  * Empty search entries now show the "Search" placeholder text.
  * Many accessibility issues were found (due to gla11y) and fixed.
  * Update translations.
* Sun Mar 29 2020 Aaron Stern <ukbeast89@protonmail.com>
- Update to version 4.0.2
  * Fixed Unicode errors on the tracklist view
  * Fixed icon display on Plasma/Wayland
  * Translation updates: Asturian, Catalan, Chinese
    (Simplified), Croatian, Danish, Finnish, Hindi, Italian,
    Portuguese, Spanish, Swedish, Turkish.
* Sun Sep 29 2019 Aaron Stern <ukbeast89@protonmail.com>
- Added needed python2-bsddb3 requirement.
* Sat Jun 15 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 4.0.0 (changes since 4.0.0~rc3):
  * ipconsole: Do not swallow ImportErrors
  * Equaliser: Save present correctly.
  * Fix unicode issue in saved playlists.
  * Fix rating setting in playlists.
  * Fix SmartPlaylists with timestamps.
  * Improve support for AlbumArtist: collection pane,
    playlist column, track properties
  * Moodbar improvements.
  * Many tags are now directly editable in the playlist view.
  * Drop support for HAL and UDisks v1.
  * Fix playlist column editing click/drag issues.
  * F2 now also triggers track tag editing.
  * Fix accelerators issue that caused a bug in the audioscrobbler
    plugin.
  * Remove AWN plugin.
  * panel/playlists: Fix some drag&drop stuff.
  * Many minor fixes and enhancements
  * Update translations.
- Stop using GPG signing as upstream did not sign the tarball.
* Sat Dec 15 2018 sor.alexei@meowr.ru
- Update to version 4.0.0~rc3 (changes since 4.0.0~rc0):
  * DAAP fixes.
  * Add random shuffle mode.
  * Fix cairo issues on pygobject 3.30.
  * Fix issues reading tags when tagless media are in a collection.
  * Plugin updates for DAAP/Last.fm.
  * Fix bugs in parsing track streams.
  * SmartPlaylist bug with empty collection.
* Thu Jun 28 2018 sor.alexei@meowr.ru
- Update to version 4.0.0~rc0:
  * Add a setting to tell Gtk to use the dark theme.
  * Drag and drop fixes.
* Mon Mar 19 2018 sor.alexei@meowr.ru
- Update to version 4.0.0~beta3:
  * Massive speed improvements, can handle a 50000+ song library.
  * Improve support for reading .aif/.aiff/.aifc files.
  * Smart playlist now supports matching by a whole word.
  * Smart playlist now supports a user-specified default sort
    order.
  * Plugins cleanup.
- Use GPG signing.
* Sun Jun 18 2017 sor.alexei@meowr.ru
- Update to version 4.0.0~beta2:
  * Force usage of bsddb/bsddb3.
  * Various fixes.
* Wed May 24 2017 sor.alexei@meowr.ru
- Update to version 4.0.0~beta1:
  * No changelog available.
- Rebase exaile-no-splash-default.patch,
  exaile-mate-screensaver.patch.
- Add PGP signing.
* Wed May 10 2017 sor.alexei@meowr.ru
- Update to version 3.4.5+git20170510:
  * No changelog available.
* Wed Jan 25 2017 jengelh@inai.de
- Ensure fdupes does not run across partitions
* Thu Jan 19 2017 sor.alexei@meowr.ru
- Update to version 3.4.5+git20170110:
  * No changelog available.
- Rebase exaile-no-splash-default.patch,
  exaile-mate-screensaver.patch.
* Wed Apr 29 2015 sor.alexei@meowr.ru
- Update to 3.4.5:
  * Errors loading Smart Playlists that filter based on a playlist.
  * Missing icon issue.
  * Disable equalizer by default.
  * Translations update.
* Sat Mar 21 2015 sor.alexei@meowr.ru
- Add exaile-no-splash-default.patch to make Exaile not show splash
  screen on startup by default, Exaile starts fast enough.
- Add exaile-mate-screensaver.patch which makes screensaverpause
  plugin to work with MATE ScreenSaver.
* Mon Mar 16 2015 sor.alexei@meowr.ru
- Update to 3.4.4:
  * If you installed Exaile by Makefile, or in slightly nonstandard
    ways, translations would not actually work.
  * Catch OSError when git is not installed.
  * Fix search fail when there is a file with wrong encoding.
  * Fix playlist import error.
  * Add export playlists to right click menu on playlists tab.
  * Fix tray menu item for removing current playlist item.
* Thu Dec 18 2014 sor.alexei@meowr.ru
- Update to 3.4.3:
  * Smart Playlists with criteria involving timestamps now work.
  * Significant translations update.
* Mon Nov 10 2014 sor.alexei@meowr.ru
- Update to 3.4.2:
  * Exaile did not always update individual files when changed
    externally.
  * Add an option to 'force rescan' of files for users with
    misbehaving external tagger applications.
  * GroupTagger plugin: Potential tag loss when using externally
    modified files.
* Sun Nov  2 2014 sor.alexei@meowr.ru
- Update to 3.4.1:
  * Delay the import of modules that depend on PyGTK to after
  - -help handling.
  * Don't refuse to run as root: we're not the moral police.
    IIRC there were bugs when running as root, so message saying
    it is unsupported still prints out.
* Sun Sep 28 2014 sor.alexei@meowr.ru
- Update to 3.4.0.2 (changes since 3.3.2):
  * Audio output device can now be switched while playing songs
  * Improved unicode support
  * An option has been added to disallow playback while another
    song is playing
  * UDisks/UDisks2 support
  * Covers: cover manager improvements, saving to disk
  * Create appdata folder in Makefile
  * Playlists can be shown in multiple panes
  * The left tab panels are now closable
  * BPM counter plugin has better UI integration
  * Create playlists based on other playlists
  * Support for filtering over 20 different tag types
  * A simpler plugin API is available (but the old one still works!)
  * Plugin manager doesn't show users potentially broken plugins
    anymore
  * New plugins: console, Icecast Radio, lyricsmania, mono output,
    playlist analyzer, Soma.FM
  * Broken/old plugins removed: lyricsfly, shoutcast
  * Fixes/improvements for various plugins
- Spec cleanup.
- Remove exaile_nowindows.suse.patch.
* Sun Nov  3 2013 propstmatthias@googlemail.com
- Update to 3.3.2:
  * Tracks were sometimes selected incorrectly when searching a
    playlist
  * Sometimes the main window wouldn't appear when minimizing to
    the system tray
  * More tags supported for MP4/M4A/FLAC/OGG files
  * Locale bugs when executing --help
  * Fixed plugins: librivox
* Sun Nov 18 2012 propstmatthias@googlemail.com
- Update to 3.3.1:
  * Accessibility related fixes
  * Dynamic playlists are now working correctly
  * WMA files are properly supported now
  * Playlist import is now more robust
  * Internal tags (those starting with __) were clobbered when
    being restored to playlists, so things like ratings and other
    such things would disappear mysteriously. This is no longer
    the case.
  * Fixed plugins: ContextInfo, mini-mode, osd, last.fm
* Sat Sep 29 2012 propstmatthias@googlemail.com
- Fix python-bytecode-inconsistent-mtime.
* Fri Sep 28 2012 propstmatthias@googlemail.com
- Fix wrong date in changes.
- Fix wrong License in specfile.
- Fix broken org.service for dbus daemon (contained buildroot).
- Remove Windows-specific files from the original source.
* Fri Sep 28 2012 propstmatthias@googlemail.com
- Update to 3.3.0:
  * Lots of threading issues which resulted in hangs during
    playback and upon startup
  * Sanitize passwords from stream URLs to keep them from being
    displayed, submitted and stored
  * Asynchronous cover fetching
  * Escape XML-critical characters for ASX and XSPF playlist export
  * Improved import of media from drag drops
  * Tracks and playlist import from and export to arbitrary
    locations (like network locations)
  * Tracks are moved to the Trash by default if possible instead of
    directly deleting them
  * Various other small changes to make things behave more natural
  * Revamped cover chooser (spinner as loading indicator¹,
    thumbnail bar, cover details like source and size) and cover
    manager (better threading, faster, more progress indication,
    facelift)
  * Implement automatic scrolling during drag operations
  * Facelift and small improvements for the track properties dialog
  * New button in the playlist notebook¹ (click for new playlist,
    drop something on it to pre-fill the new playlist)
  * Ability to add arbitrary markers to the playback progress bar
    for jumping
  * Ability to restore closed playlist tabs
  * Completely new, provider-based menu system, some places not yet
    ported (allows for easy customization and extension of menus
    like e.g. rating and Last.fm Love/Unlove menu items)
  * Playlist columns ported to the provider system
  * Comments tag in the track properties and as playlist column
  * New playlist column: scheduled playback time of tracks
  * Add icons to the preferences dialogs and categories to the
    plugins list
  * Option to hide the main track info pane or only the cover widget
    within
  * Completely rewritten playlist API (cleaner, more flexible and
    extensible, move and copy tracks arbitrarily between playlists)
  * Intelligent playlist default naming (no duplicates, always takes
    free name slots)
  * Allow for randomizing a selection of tracks instead of only the
    full playlist
  * Playlist importers/exporters ported to the provider system (more
    flexible, easily extendable with additional formats)
  * Enhanced playlist recognition upon import (fast type detection,
    file extension and slow type detection)
  * Support relative paths in playlist import/export
  * Method/CLI option to export the current playlist
  * DBus service activation enabled
  * Added method for pausing
  * Added method/CLI option for formatted playback queries
  * Support albumartist for MP3/MP4
  * Properly read tags from files with non-ASCII names
  * Properly read all available covers embedded in tags and keep
    their information
  * Proper handling of an arbitrary amount of covers embedded in tags
    (cover fetching and track properties)
  * A-B Repeat: repeat segment of a track by placing two markers on
    the playback progress bar
  * BPM Counter: manually set BPM per track
  * Group Tagger: add custom labels to tracks and gather tracks by
    these labels (via smart playlist filters)
  * History: keep history of played tracks and export them to a
    playlist
  * Inhibit Suspend: prevent suspend on e.g. notebooks during playback
  * Last.fm Loved Tracks: love/unlove tracks, see loved state of tracks
  * Main Menu Button: moves the main menu into a single Chrome-like button
  * OSD: formerly core, now completely rewritten with new options
  * Preview Device: allows playing audio over a secondary device,
    useful for DJs
  * Wikipedia: information about the current artist
  * Various fixes and improvements for other plugins
* Thu Oct 13 2011 prusnak@opensuse.org
- spec cleanup
* Sun Jul 24 2011 propstmatthias@googlemail.com
- update to 0.3.2.2
  + We are now capable of using the external bsddb3 module if distributions disable
    python2’s deprecated built-in bsddb support, as Arch Linux did recently.
  + Compatibility with newer Ex Falso releases was restored to the Ex Falso plugin.
  + Exaile no longer stops scanning when it encounters permissions errors
* Tue Feb 15 2011 propstmatthias@googlemail.com
- update to 0.3.2.1
  + The shoutcast plugin has been removed from the default install, as shoucast has changed their API
    and the new terms of service are not compatible with our license.
  + The default lyrics provider was changed to lyricwiki, as lyricfly no longer works properly.
  + A bug that prevented Exaile from running on very recent versions of pygobject was fixed.
  + A bug preventing files from being added via the CLI was fixed.
  + Prevent running as root
  + fixed some minor issues
* Wed Jun 30 2010 propstmatthias@googlemail.com
- update to 0.3.2.0
  + No new features since the rc, just a smattering of minor bugfixes.
* Tue Jun  1 2010 propstmatthias@googlemail.com
- update to 0.3.1.2
  + Full python2.5 compatibility was restored
  + A bug resulting in unexpected duplicate playlist entries was fixed
  + Several stability and interface issues were resolved
* Wed May 19 2010 prusnak@opensuse.org
- cleanup spec file
* Tue Apr 13 2010 propstmatthias@googlemail.com
- update to 0.3.1.1
  + an issue that could cause exaile to be unable to run without installing was fixed
  + the tagger now only writes to changed files, not all selected files
  + an edge case that could result in new playlists not being saved was resolved
  + album shuffle now properly respects discnumber tags and double-digit tracknumber tags
  + arguments passed to the installed exaile script are now properly quoted,
    resolving issues with using filenames that had spaces or unusual characters in them.
  + a number of additional minor issues were resolved
* Sat Mar 20 2010 propstmatthias@googlemail.com
- fixed exaile for opensuse 11.0
* Thu Mar 18 2010 propstmatthias@googlemail.com
- update to 0.3.1.0
  + A completely revamped and much more powerful tag editor
  + An equalizer!
  + Collection panel should now be faster
  + Better support for non-standard filename encodings
  + A standalone lyrics pane plugin
  + Plugins for DAAP music sharing support
  + Better display of compilation albums
* Sun Nov 22 2009 propstmatthias@googlemail.com
- added patch exaile_p1_fix_sysconfwarn.patch
  +uses settings.conf instead of settings.ini
* Sun Nov 22 2009 propstmatthias@googlemail.com
- removed MP in Release name
- removed explicit requires
- changed buildarch to noarch
* Wed Nov 11 2009 propstmatthias@googlemail.com
- update to 0.3.0.2:
  +fixed 20 bugs
- added librsvg and librsvg-devel requirements for building
- fixed some errors in rpm found by prmlint
* Tue Nov  3 2009 propstmatthias@googlemail.com
- rebuild this version to fix some bugs
* Thu Sep 10 2009 propstmatthias@googlemail.com
- update to bug fix version of exaile
- fixed 14 bugs from previous version
* Mon Aug 31 2009 propstmatthias@googlemail.com
- update to final release of exaile
* Wed Aug 19 2009 propstmatthias@googlemail.com
- update to 0.3.0b1
* Wed Jul 22 2009 propstmatthias@googlemail.com
- update to 0.3.0a3
* Tue Jun  2 2009 propstmatthias@googlemail.com
- switched to newest alpha
* Thu May 28 2009 propstmatthias@googlemail.com
- weekly build
* Thu May 14 2009 propstmatthias@googlemail.com
- new weekly build
* Mon May 11 2009 propstmatthias@googlemail.com
- used opensuse build service for building
- made some changes in specfile
* Wed Apr 22 2009 propstmatthias@googlemail.com
- new weekly build
* Wed Apr 15 2009 propstmatthias@googlemail.com
- new weekly build
* Wed Apr  8 2009 propstmatthias@googlemail.com
- new weekly build
* Thu Apr  2 2009 propstmatthias@googlemail.com
- builded weekly build
- added missing file to files list
* Thu Apr  2 2009 propstmatthias@googlemail.com
- fixed path to exaile.dektop
- fixed Makefile
* Wed Apr  1 2009 propstmatthias@googlemail.com
- cleaned up the specfile
- changed Distribution to Vendor
- added BuildRoot
- made package more suse conform
* Sun Mar  8 2009 propstmatthias@googlemail.com
- initial build for Opensuse 11.0
